@@ -31,11 +31,11 @@ public:
     /**
      * Destructor
      */
-    virtual ~WindowDefinitionListWidget();
+    ~WindowDefinitionListWidget() override;
 
     void setWindowDefinitions(KHotKeys::Windowdef_list *windowdef_list);
 
-    bool isChanged() const Q_DECL_OVERRIDE;
+    bool isChanged() const override;
 
 private:
     void emitChanged(bool);
@@ -48,8 +48,8 @@ private Q_SLOTS:
     void slotNew(bool);
 
 protected:
-    void doCopyFromObject() Q_DECL_OVERRIDE;
-    void doCopyToObject() Q_DECL_OVERRIDE;
+    void doCopyFromObject() override;
+    void doCopyToObject() override;
 
 private:
     // The Windowdefinition list
@@ -87,12 +87,12 @@ public:
         connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     }
 
-    ~WindowDefinitionListDialog()
+    ~WindowDefinitionListDialog() override
     {
         def = nullptr;
     }
 
-    void accept() Q_DECL_OVERRIDE
+    void accept() override
     {
         def->copyToObject();
         QDialog::accept();
